Documentation
¶
Rendered for windows/amd64
Overview ¶
Package winhello implements a keyring backend backed by Windows Hello.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrKeyNotFound = errors.New("the specified item could not be found in the keyring")
ErrKeyNotFound is returned by Get when the item is not on the keyring.
Functions ¶
This section is empty.
Types ¶
type Backend ¶
type Backend struct {
// contains filtered or unexported fields
}
Backend stores items in the Windows Credential Manager, encrypted with a Windows Hello protected key.
Click to show internal directories.
Click to hide internal directories.